@@ -1,5 +1,5 @@
 /*
- * $Id: xpmicon.h,v 1.1.1.1 2001/02/12 22:26:11 xtifr Exp $
+ * $Id: xpmicon.h,v 1.2 2003/10/01 22:44:19 xtifr Exp $
  *
  * part of wmrack
  *
@@ -7,8 +7,8 @@
  *
  * Copyright (c) 1997 by Oliver Graf <ograf@fga.de>
  */
-#ifndef _XPMICON_H
-#define _XPMICON_H
+#ifndef WMRACK_XPMICON_H_
+#define WMRACK_XPMICON_H_
 
 /* Xpm struct */
 typedef struct {
@@ -35,12 +35,9 @@ extern XpmIcon rackXpm[];
 extern int curRack;
 extern char *ledAlphabet;
 
-#define currentXpm(w) rackXpm[curRack].##w
-#define ledXpm(x,w) rackXpm[x].##w
-
 int xpm_setDefaultAttr(Display *disp, Drawable draw, char *color, char *back);
 int xpm_loadSet(Display *disp, Drawable draw, char *filename);
 int xpm_setDefaultSet(Display *disp, Drawable draw, int num);
 void xpm_freeSet(Display *disp);
 
-#endif
+#endif /* WMRACK_XPMICON_H_ */
